<?php

// Constant declaration
const MODX_API_MODE = true;

// Require main project file
require dirname(__FILE__, 5) . '/index.php';

/**
 * @var modX $modx
 * 
 * The ModX service, responsible for error handling and logging.
 */
$modx->getService('error', 'error.modError');

$orderId = $_GET['orderId'] ?? null;

try {
    // Check if orderId is set and not empty
    if (empty($orderId)) {
        throw new \Exception('Order ID is empty.');
    }
    
    /**
     * @var miniShop2 $miniShop2
     * 
     * The miniShop2 service, responsible for payment classes loading.
     */
    $miniShop2 = $modx->getService('minishop2');
    $miniShop2->loadCustomClasses('payment');

    // Check if the VtbPay class exists
    if (!class_exists('VtbPay')) {
        throw new \Exception('Could not load payment class "VtbPay".');
    }

    /**
     * @var msPaymentInterface|VtbPay $handler
     * 
     * Initialize the payment handler.
     */
    $handler = new VtbPay($modx->newObject(msPayment::class));

    /**
     * @var msOrder $order
     * 
     * Retrieve the order by id from the modX object.
     */
    $order = $modx->getObject(msOrder::class, ['id' => (int)$orderId]);

    // If order exists
    if (empty($order)) {
        // Log the error if order could not be retrieved
        throw new \Exception('Order not found.');
    }
      
    $receive = $handler->receive($order);

    // Set parameters and context
    $params['msorder'] = (int)$orderId;
    $context = $order->get('context');

    // Set default success and failure URLs
    $success = $failure = $modx->getOption('site_url');
    
    // If success page id is set, make URL for it
    if ($id = $modx->getOption('ms2_payment_vtbpay_success_id', null, 0)) {
        $success = $modx->makeUrl($id, $context, $params, 'full');
    }
    // If failure page id is set, make URL for it
    if ($id = $modx->getOption('ms2_payment_vtbpay_failure_id', null, 0)) {
        $failure = $modx->makeUrl($id, $context, $params, 'full');
    }

    // Decide on the redirect URL based on the $receive result
    $redirect = $receive ? $success : $failure;
    // Redirect to the determined URL
    $modx->sendRedirect($redirect);
    
} catch (\Exception $e) {
    
    $modx->setLogLevel(modX::LOG_LEVEL_ERROR);
    
    $modx->setLogTarget([
       'target' => 'FILE',
       'options' => [
           'filename' => 'vtbpay.log'
        ]
    ]);

    $modx->log(
        modX::LOG_LEVEL_ERROR, sprintf(
        'Request return page > VtbPay Exception: %s; Order id: %s', 
        $e->getMessage(), 
        $orderId ?: ''
    ));
    
    die($e->getMessage() . ' <a href="/">Go Home</a>');
}